@@ -1,18 +1,33 @@
 import logging
 import os
+import regex
 
-import ancpbids.plugins
+from . import plugins
 from . import files
 from . import model
 from . import utils
 from .plugin import get_plugins, load_plugins_by_package, DatasetPlugin, WritingPlugin, ValidationPlugin, SchemaPlugin
-from .plugins.plugin_query import XPathQuery, BoolExpr, Select, EqExpr, AnyExpr, AllExpr, ReExpr, CustomOpExpr, \
-    EntityExpr, DatatypeExpr
+from .plugins.plugin_query import BoolExpr, Select, EqExpr, AnyExpr, AllExpr, ReExpr, CustomOpExpr, \
+    EntityExpr
 
 LOGGER = logging.getLogger("ancpbids")
 
+ENTITIES_PATTERN = regex.compile(r'(([^\W_]+)-([^\W_]+)_)+([^\W_]+)((\.[^\W_]+)+)')
+
 
 def load_dataset(base_dir: str):
+    """
+    Loads a dataset given its directory path on the file system.
+
+    .. code-block::
+
+        from ancpbids import load_dataset, validate_dataset
+        dataset_path = 'path/to/your/dataset'
+        dataset = load_dataset(dataset_path)
+
+    :param base_dir: the dataset path to load from
+    :return: an object instance of type :py:class:`ancpbids.model.Dataset` which represents the dataset as an in-memory graph
+    """
     ds = model.Dataset()
     ds._schema = model
     ds.name = os.path.basename(base_dir)
@@ -29,7 +44,28 @@ def save_dataset(ds: model.Dataset, target_dir: str, context_folder: model.Folde
         dsplugin.execute(ds, target_dir, context_folder=context_folder)
 
 
-def validate_dataset(dataset: model.Dataset, plugin_acceptor=None):
+def validate_dataset(dataset: model.Dataset) -> ValidationPlugin.ValidationReport:
+    """
+    Validates a dataset and returns a report object containing any detected validation errors.
+
+    Example:
+
+    .. code-block::
+
+        report = validate_dataset(dataset)
+        for message in report.messages:
+            print(message)
+        if report.has_errors():
+            raise "The dataset contains validation errors, cannot continue".
+
+
+    :param dataset: the dataset to validate
+    :return: a report object containing any detected validation errors or warning
+    """
+    return _internal_validate_dataset(dataset)
+
+
+def _internal_validate_dataset(dataset: model.Dataset, plugin_acceptor=None):
     validation_plugins = get_plugins(ValidationPlugin)
     report = ValidationPlugin.ValidationReport()
     for validation_plugin in validation_plugins:
@@ -40,12 +76,12 @@ def validate_dataset(dataset: model.Dataset, plugin_acceptor=None):
     return report
 
 
-def write_derivative(ds: model.Dataset, derivative: model.DerivativeFolder):
+def write_derivative(ds: model.Dataset, derivative: model.Folder):
     save_dataset(ds, target_dir=ds.get_absolute_path(), context_folder=derivative)
 
 
 # load system plugins using lowest rank value
-load_plugins_by_package(ancpbids.plugins, ranking=0, system=True)
+load_plugins_by_package(plugins, ranking=0, system=True)
 
 # execute all SchemaPlugins, these plugins may monkey-patch the schema
 for pl in get_plugins(SchemaPlugin):
@@ -60,7 +96,6 @@ eq = EqExpr
 re = ReExpr
 op = CustomOpExpr
 entity = EntityExpr
-datatype = DatatypeExpr
 
 from . import _version
 
