@@ -1,4 +1,5 @@
 import re
+from fnmatch import fnmatch
 
 from ancpbids import model
 from ancpbids.plugin import SchemaPlugin
@@ -33,7 +34,11 @@ class AllExpr(BoolExpr):
         self.bool_ops = bool_ops
 
     def eval(self, context) -> bool:
-        return all([op.eval(context) for op in self.bool_ops])
+        for op in self.bool_ops:
+            if not op.eval(context):
+                # early exit to prevent evaluating remaining ops
+                return False
+        return True
 
 
 class EqExpr(CompExpr):
@@ -65,23 +70,24 @@ class CustomOpExpr(CompExpr):
         return self.op(context)
 
 
+class FnMatchExpr(CompExpr):
+    def __init__(self, attr: property, pattern):
+        self.attr = attr
+        self.pattern = pattern
+
+    def eval(self, context) -> bool:
+        value = self.attr.fget(context)
+        return value is not None and fnmatch(value, self.pattern)
+
+
 class EntityExpr(CompExpr):
-    def __init__(self, key: model.EntityEnum, value, op=EqExpr):
+    def __init__(self, key: model.EntityEnum, value, op=FnMatchExpr):
         self.op = AllExpr(EqExpr(model.EntityRef.key, key.entity_), op(model.EntityRef.value, value))
 
-    def eval(self, context) -> bool:
+    def eval(self, context: model.Artifact) -> bool:
         if not isinstance(context, model.Artifact):
-            raise ValueError('Entity expression can only operate on model.Artifact')
-        return any([self.op.eval(e) for e in context.entities])
-
-
-class DatatypeExpr(CompExpr):
-    def __init__(self, key: model.DatatypeEnum, value, op=EqExpr):
-        self.op = AllExpr(EqExpr(model.EntityRef.key, key.entity_), op(model.EntityRef.value, value))
-
-    def eval(self, context) -> bool:
-        if not isinstance(context, model.Artifact):
-            raise ValueError('Datatype expression can only operate on model.Artifact')
+            # for non-Artifacts, for example File, just return false
+            return False
         return any([self.op.eval(e) for e in context.entities])
 
 
@@ -107,50 +113,24 @@ class Select:
     def get_file_paths(self):
         return self._exec(model.File.get_relative_path)
 
+    def get_file_paths_absolute(self):
+        return self._exec(model.File.get_absolute_path)
+
     def get_artifacts(self):
         # TODO filter by Artifact instances
         return self.objects()
 
-    def objects(self):
-        return self._exec(lambda m: m)
-
-
-class Query:
-    def __init__(self, dataset: model.Dataset):
-        self.dataset = dataset
-        self.id2x = {}
-        self.x2id = {}
-        self.root = dataset.to_etree(id2x=self.id2x, x2id=self.x2id, nsmap_={})
-
-    def execute(self, expr, search_node=None, return_model_objects=True):
-        raise NotImplemented()
-
-
-class XPathQuery(Query):
-    def __init__(self, dataset: model.Dataset):
-        super(XPathQuery, self).__init__(dataset)
-
-    def execute(self, expr, search_node=None, return_lxml_objects=False):
-        context = self.root
-        if search_node:
-            context = search_node
-        result = context.xpath(expr)
-        if return_lxml_objects:
-            return result
-        result = list(map(lambda e: self.x2id[e] if e in self.x2id else e, result))
+    def objects(self, as_list=False):
+        result = self._exec(lambda m: m)
+        if as_list:
+            result = list(result)
         return result
 
 
-def query(ds: model.Dataset, expr: str):
-    query_ = XPathQuery(ds)
-    return query_.execute(expr), query_
-
-
 def select(context: model.Model, target_type):
     return Select(context, target_type)
 
 
 class QuerySchemaPlugin(SchemaPlugin):
     def execute(self, schema: model):
-        schema.Dataset.query = query
-        schema.Dataset.select = select
+        schema.Model.select = select
